==> owncloud-10.2.0.zip: owncloud/apps/files/l10n/oc.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Espaci d'emmagazinatge temporàriament indisponible",
    "Storage invalid" : "Supòrt d'emmagazinatge pas valable",
    "Unknown error" : "Error Desconeguda ",
    "All files" : "Totes los fichièrs",
    "Saved" : "Enregistrat",
    "File could not be found" : "Aqueste fichièr es pas estat trobat.",
    "Home" : "Mos fichièrs",
    "Close" : "Tampar",
    "Favorites" : "Favorits",
    "Could not create folder \"{dir}\"" : "Impossible de crear lo dorsièr \"{dir}\"",
    "Upload cancelled." : "Mandadís anullat.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Impossible de mandar {filename} perque s'agís d'un repertòri o d'un fichièr de talha nulla",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Espaci liure insufisent : ensajatz de mandar {size1} mas solament {size2} son disponibles",
    "Target folder \"{dir}\" does not exist any more" : "Lo dorsièr de destinacion « {dir} » existís pas mai",
    "Not enough free space" : "Pas pro d'espaci liure",
    "Uploading..." : "Mandadís en cors…",
    "..." : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} sus {totalSize} ({bitrate})",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Lo mandadís del fichièr es en cors. Quitar aquesta pagina ara anullarà lo mandadís del fichièr.",
    "Actions" : "Accions",
    "Download" : "Telecargar",
    "Rename" : "Renomenar",
    "Delete" : "Suprimir",
    "Disconnect storage" : "Desconnectar aqueste supòrt d'emmagazinatge",
    "Unshare" : "Partejar pas",
    "Could not load info for file \"{file}\"" : "Impossible de cargar l'info pel fichièr \"{file}\"",
    "Files" : "Fichièrs",
    "Details" : "Detalhs",
    "Select" : "Seleccionar",
    "Pending" : "En espèra",
    "Unable to determine date" : "Impossible de determinar la data",
    "Invalid path" : "Camin invalid",
    "This operation is forbidden" : "L'operacion es interdicha",
    "This directory is unavailable, please check the logs or contact the administrator" : "Aqueste repertòri es pas disponible. Consultatz los logs o contactatz vòstre administrator",
    "Could not move \"{file}\", target exists" : "Impossible de desplaçar \"{file}\", la cibla existís",
    "Could not move \"{file}\"" : "Impossible de desplaçar \"{file}\"",
    "{newName} already exists" : "{newName} existís ja",
    "Could not rename \"{fileName}\", it does not exist any more" : "Impossible de renomenar \"{file}\", existís pas mai",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Lo nom \"{targetName}\" es ja utilizat dins lo dorsièr \"{dir}\". Mercé de causir un nom diferent.",
    "Could not rename \"{fileName}\"" : "Impossible de renomenar \"{fileName}\"",
    "Could not create file \"{file}\"" : "Impossible de crear lo fichièr \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Impossible de crear lo fichièr \"{file}\" perque existís ja",
    "Could not create folder \"{dir}\" because it already exists" : "Impossible de crear lo dorsièr \"{dir}\" perque existís ja",
    "Error deleting file \"{fileName}\"." : "Error pendent la supression del fichièr \"{fileName}\".",
    "Name" : "Nom",
    "Size" : "Talha",
    "Modified" : "Modificat",
    "_%n folder_::_%n folders_" : ["%n dorsièr","%n dorsièrs"],
    "_%n file_::_%n files_" : ["%n fichièr","%n fichièrs"],
    "{dirs} and {files}" : "{dirs} e {files}",
    "_including %n hidden_::_including %n hidden_" : ["inclure %n amagat","inclure %n amagats"],
    "You don’t have permission to upload or create files here" : "Avètz pas la permission d'apondre de fichièrs aicí",
    "_Uploading %n file_::_Uploading %n files_" : ["Mandadís de %n fichièr","Mandadís de %n fichièrs"],
    "New" : "Novèl",
    "\"{name}\" is an invalid file name." : "\"{name}\" es pas un nom de fichièr valid.",
    "File name cannot be empty." : "Lo nom de fichièr pòt pas èsser void.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "L'espaci d'emmagazinatge de {owner} es plen. Los fichièrs pòdon pas mai èsser meses a jorn o sincronizats !",
    "Your storage is full, files can not be updated or synced anymore!" : "Vòstre espaci d'emmagazinatge es plen, los fichièrs pòdon pas mai èsser aponduts o sincronizats !",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "L'espaci d'emmagazinatge de {owner} es gaireben plen ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Vòstre espace d'emmagazinatge es gaireben plen ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["correspond a '{filter}'","correspondon a '{filter}'"],
    "Path" : "Camin",
    "_%n byte_::_%n bytes_" : ["%n octet","%n octets"],
    "Favorited" : "Marcat coma favorit",
    "Favorite" : "Favorit",
    "Folder" : "Dorsièr",
    "New folder" : "Novèl dorsièr",
    "{newname} already exists" : "{new_name} existís ja",
    "Upload" : "Cargament",
    "An error occurred while trying to update the tags" : "Una error s'es produsida al moment de la mesa a jorn de las etiquetas",
    "A new file or folder has been <strong>created</strong>" : "Un novèl fichièr o repertòri es estat <strong>creat</strong>",
    "A file or folder has been <strong>changed</strong>" : "Un fichièr o un repertòri es estat <strong>modificat</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limitar las notifications a çò que concernís la creacion e la modificacion de vòstres <strong>fichièrs favorits</strong> <em>(Flux unicament)</em>",
    "A file or folder has been <strong>deleted</strong>" : "Un fichièr o un repertòri es estat <strong>suprimit</strong>",
    "A file or folder has been <strong>restored</strong>" : "Un fichièr o un repertòri es estat <strong>restablit</strong>",
    "You created %1$s" : "Avètz creat %1$s",
    "%2$s created %1$s" : "%2$s a creat %1$s",
    "%1$s was created in a public folder" : "%1$s es estat creat dins un dorsièr public",
    "You changed %1$s" : "Avètz modificat %1$s",
    "%2$s changed %1$s" : "%2$s a modificat %1$s",
    "You deleted %1$s" : "Avètz suprimit %1$s",
    "%2$s deleted %1$s" : "%2$s a suprimit %1$s",
    "You restored %1$s" : "Avètz restablit %1$s",
    "%2$s restored %1$s" : "%2$s a restablit %1$s",
    "Changed by %2$s" : "Modificat per %2$s",
    "Deleted by %2$s" : "Suprimit per %2$s",
    "Restored by %2$s" : "Restablit per %2$s",
    "Upload (max. %s)" : "Mandadís (max. %s)",
    "File handling" : "Gestion de fichièrs",
    "Maximum upload size" : "Talha max. de mandadís",
    "max. possible: " : "Max. possible :",
    "Save" : "Salvar",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Amb PHP-FPM se pòdon passar 5 minutas per que los cambiaments s'apliquen.",
    "Missing permissions to edit from here." : "Manca de permissions per editar a partir d'aicí.",
    "Settings" : "Paramètres",
    "Show hidden files" : "Afichar los fichièrs amagats",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Utilizatz aquesta adreça per <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">accedir a vòstres fichièrs per WebDAV</a>",
    "No files in here" : "Pas cap de fichièr aicí",
    "Upload some content or sync with your devices!" : "Depausatz de contengut o sincronizatz vòstres aparelhs !",
    "No entries found in this folder" : "Cap d'entrada pas trobada dins aqueste dorsièr",
    "Select all" : "Seleccionar tot",
    "Upload too large" : "Mandadís tròp voluminós",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Los fichièrs qu'ensajatz de mandar depassan la talha maximala de mandadís permesa per aqueste servidor.",
    "No favorites" : "Pas cap de favorit",
    "Files and folders you mark as favorite will show up here" : "Los fichièrs e dorsièrs aponduts a vòstres favorits apareisseràn aicí",
    "Text file" : "Fichièr tèxte",
    "New text file.txt" : "Novèl fichièr tèxte .txt",
    "Unknown user" : "Utilizaire desconegut"
},
"nplurals=2; plural=(n > 1);");

==> owncloud-10.4.0.zip: owncloud/apps/files/l10n/oc.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Espaci d'emmagazinatge temporàriament indisponible",
    "Storage invalid" : "Supòrt d'emmagazinatge pas valable",
    "Unknown error" : "Error Desconeguda ",
    "All files" : "Totes los fichièrs",
    "File could not be found" : "Aqueste fichièr es pas estat trobat.",
    "Home" : "Mos fichièrs",
    "Close" : "Tampar",
    "Favorites" : "Favorits",
    "Could not create folder \"{dir}\"" : "Impossible de crear lo dorsièr \"{dir}\"",
    "Upload cancelled." : "Mandadís anullat.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Impossible de mandar {filename} perque s'agís d'un repertòri o d'un fichièr de talha nulla",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Espaci liure insufisent : ensajatz de mandar {size1} mas solament {size2} son disponibles",
    "Target folder \"{dir}\" does not exist any more" : "Lo dorsièr de destinacion « {dir} » existís pas mai",
    "Not enough free space" : "Pas pro d'espaci liure",
    "Uploading..." : "Mandadís en cors…",
    "..." : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} sus {totalSize} ({bitrate})",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Lo mandadís del fichièr es en cors. Quitar aquesta pagina ara anullarà lo mandadís del fichièr.",
    "Actions" : "Accions",
    "Download" : "Telecargar",
    "Rename" : "Renomenar",
    "Delete" : "Suprimir",
    "Disconnect storage" : "Desconnectar aqueste supòrt d'emmagazinatge",
    "Unshare" : "Partejar pas",
    "Could not load info for file \"{file}\"" : "Impossible de cargar l'info pel fichièr \"{file}\"",
    "Files" : "Fichièrs",
    "Details" : "Detalhs",
    "Select" : "Seleccionar",
    "Pending" : "En espèra",
    "Unable to determine date" : "Impossible de determinar la data",
    "Invalid path" : "Camin invalid",
    "This operation is forbidden" : "L'operacion es interdicha",
    "This directory is unavailable, please check the logs or contact the administrator" : "Aqueste repertòri es pas disponible. Consultatz los logs o contactatz vòstre administrator",
    "group" : "grop",
    "Remote share" : "Partiment distant",
    "Could not move \"{file}\", target exists" : "Impossible de desplaçar \"{file}\", la cibla existís",
    "Could not move \"{file}\"" : "Impossible de desplaçar \"{file}\"",
    "{newName} already exists" : "{newName} existís ja",
    "Could not rename \"{fileName}\", it does not exist any more" : "Impossible de renomenar \"{file}\", existís pas mai",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Lo nom \"{targetName}\" es ja utilizat dins lo dorsièr \"{dir}\". Mercé de causir un nom diferent.",
    "Could not rename \"{fileName}\"" : "Impossible de renomenar \"{fileName}\"",
    "Could not create file \"{file}\"" : "Impossible de crear lo fichièr \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Impossible de crear lo fichièr \"{file}\" perque existís ja",
    "Could not create folder \"{dir}\" because it already exists" : "Impossible de crear lo dorsièr \"{dir}\" perque existís ja",
    "Error deleting file \"{fileName}\"." : "Error pendent la supression del fichièr \"{fileName}\".",
    "Name" : "Nom",
    "Size" : "Talha",
    "Modified" : "Modificat",
    "_%n folder_::_%n folders_" : ["%n dorsièr","%n dorsièrs"],
    "_%n file_::_%n files_" : ["%n fichièr","%n fichièrs"],
    "{dirs} and {files}" : "{dirs} e {files}",
    "_including %n hidden_::_including %n hidden_" : ["inclure %n amagat","inclure %n amagats"],
    "You don’t have permission to upload or create files here" : "Avètz pas la permission d'apondre de fichièrs aicí",
    "_Uploading %n file_::_Uploading %n files_" : ["Mandadís de %n fichièr","Mandadís de %n fichièrs"],
    "New" : "Novèl",
    "Unknown user" : "Utilizaire desconegut",
    "\"{name}\" is an invalid file name." : "\"{name}\" es pas un nom de fichièr valid.",
    "File name cannot be empty." : "Lo nom de fichièr pòt pas èsser void.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "L'espaci d'emmagazinatge de {owner} es plen. Los fichièrs pòdon pas mai èsser meses a jorn o sincronizats !",
    "Your storage is full, files can not be updated or synced anymore!" : "Vòstre espaci d'emmagazinatge es plen, los fichièrs pòdon pas mai èsser aponduts o sincronizats !",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "L'espaci d'emmagazinatge de {owner} es gaireben plen ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Vòstre espace d'emmagazinatge es gaireben plen ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["correspond a '{filter}'","correspondon a '{filter}'"],
    "Path" : "Camin",
    "_%n byte_::_%n bytes_" : ["%n octet","%n octets"],
    "Favorited" : "Marcat coma favorit",
    "Favorite" : "Favorit",
    "Folder" : "Dorsièr",
    "New folder" : "Novèl dorsièr",
    "{newname} already exists" : "{new_name} existís ja",
    "Upload" : "Cargament",
    "An error occurred while trying to update the tags" : "Una error s'es produsida al moment de la mesa a jorn de las etiquetas",
    "A new file or folder has been <strong>created</strong>" : "Un novèl fichièr o repertòri es estat <strong>creat</strong>",
    "A file or folder has been <strong>changed</strong>" : "Un fichièr o un repertòri es estat <strong>modificat</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limitar las notifications a çò que concernís la creacion e la modificacion de vòstres <strong>fichièrs favorits</strong> <em>(Flux unicament)</em>",
    "A file or folder has been <strong>deleted</strong>" : "Un fichièr o un repertòri es estat <strong>suprimit</strong>",
    "A file or folder has been <strong>restored</strong>" : "Un fichièr o un repertòri es estat <strong>restablit</strong>",
    "You created %1$s" : "Avètz creat %1$s",
    "%2$s created %1$s" : "%2$s a creat %1$s",
    "%1$s was created in a public folder" : "%1$s es estat creat dins un dorsièr public",
    "You changed %1$s" : "Avètz modificat %1$s",
    "%2$s changed %1$s" : "%2$s a modificat %1$s",
    "You deleted %1$s" : "Avètz suprimit %1$s",
    "%2$s deleted %1$s" : "%2$s a suprimit %1$s",
    "You restored %1$s" : "Avètz restablit %1$s",
    "%2$s restored %1$s" : "%2$s a restablit %1$s",
    "Changed by %2$s" : "Modificat per %2$s",
    "Deleted by %2$s" : "Suprimit per %2$s",
    "Restored by %2$s" : "Restablit per %2$s",
    "Upload (max. %s)" : "Mandadís (max. %s)",
    "Settings" : "Paramètres",
    "Show hidden files" : "Afichar los fichièrs amagats",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Utilizatz aquesta adreça per <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">accedir a vòstres fichièrs per WebDAV</a>",
    "No files in here" : "Pas cap de fichièr aicí",
    "Upload some content or sync with your devices!" : "Depausatz de contengut o sincronizatz vòstres aparelhs !",
    "No entries found in this folder" : "Cap d'entrada pas trobada dins aqueste dorsièr",
    "Select all" : "Seleccionar tot",
    "Upload too large" : "Mandadís tròp voluminós",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Los fichièrs qu'ensajatz de mandar depassan la talha maximala de mandadís permesa per aqueste servidor.",
    "No favorites" : "Pas cap de favorit",
    "Files and folders you mark as favorite will show up here" : "Los fichièrs e dorsièrs aponduts a vòstres favorits apareisseràn aicí",
    "Text file" : "Fichièr tèxte",
    "New text file.txt" : "Novèl fichièr tèxte .txt"
},
"nplurals=2; plural=(n > 1);");
